@@ -1,7 +1,8 @@
 from __future__ import annotations
 
 import json
-from typing import Any, Callable, Dict, List, Optional, Union
+from functools import lru_cache
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 import requests
 
@@ -19,7 +20,7 @@ class HttpRequests:
         self.config = config
         self.headers = {
             "Authorization": f"Bearer {self.config.api_key}",
-            "User-Agent": qualified_version(),
+            "User-Agent": _build_user_agent(config.client_agents),
         }
 
     def send_request(
@@ -33,7 +34,13 @@ class HttpRequests:
             self.headers["Content-Type"] = content_type
         try:
             request_path = self.config.url + "/" + path
-            if isinstance(body, bytes):
+            if http_method.__name__ == "get":
+                request = http_method(
+                    request_path,
+                    timeout=self.config.timeout,
+                    headers=self.headers,
+                )
+            elif isinstance(body, bytes):
                 request = http_method(
                     request_path,
                     timeout=self.config.timeout,
@@ -101,3 +108,12 @@ class HttpRequests:
             return HttpRequests.__to_json(request)
         except requests.exceptions.HTTPError as err:
             raise MeilisearchApiError(str(err), request) from err
+
+
+@lru_cache(maxsize=1)
+def _build_user_agent(client_agents: Optional[Tuple[str]] = None) -> str:
+    user_agent = qualified_version()
+    if not client_agents:
+        return user_agent
+
+    return f"{user_agent};{';'.join(client_agents)}"
