@@ -8,7 +8,7 @@ import hashlib
 import hmac
 import json
 import re
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 from urllib import parse
 
 from meilisearch._httprequests import HttpRequests
@@ -16,7 +16,7 @@ from meilisearch.config import Config
 from meilisearch.errors import MeilisearchError
 from meilisearch.index import Index
 from meilisearch.models.key import Key, KeysResults
-from meilisearch.models.task import TaskInfo
+from meilisearch.models.task import Task, TaskInfo, TaskResults
 from meilisearch.task import TaskHandler
 
 
@@ -29,7 +29,11 @@ class Client:
     """
 
     def __init__(
-        self, url: str, api_key: Optional[str] = None, timeout: Optional[int] = None
+        self,
+        url: str,
+        api_key: Optional[str] = None,
+        timeout: Optional[int] = None,
+        client_agents: Optional[Tuple[str]] = None,
     ) -> None:
         """
         Parameters
@@ -38,8 +42,14 @@ class Client:
             The url to the Meilisearch API (ex: http://localhost:7700)
         api_key:
             The optional API key for Meilisearch
+        timeout (optional):
+            The amount of time in seconds that the client will wait for a response before timing
+            out.
+        client_agents (optional):
+            Used to send additional client agent information for clients extending the functionality
+            of this client.
         """
-        self.config = Config(url, api_key, timeout=timeout)
+        self.config = Config(url, api_key, timeout=timeout, client_agents=client_agents)
 
         self.http = HttpRequests(self.config)
 
@@ -59,12 +69,12 @@ class Client:
         -------
         task_info:
             TaskInfo instance containing information about a task to track the progress of an asynchronous process.
-            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return Index.create(self.config, uid, options)
 
@@ -79,13 +89,13 @@ class Client:
         Returns
         -------
         task_info:
-            Dictionary containing a task to track the informations about the progress of an asynchronous process.
-            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+            TaskInfo instance containing information about a task to track the progress of an asynchronous process.
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
 
         task = self.http.delete(f"{self.config.paths.index}/{uid}")
@@ -98,7 +108,7 @@ class Client:
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the get indexes route: https://docs.meilisearch.com/reference/api/indexes.html#list-all-indexes
+            parameters accepted by the get indexes route: https://www.meilisearch.com/docs/reference/api/indexes#list-all-indexes
 
         Returns
         -------
@@ -108,7 +118,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         if parameters is None:
             parameters = {}
@@ -131,7 +141,7 @@ class Client:
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the get indexes route: https://docs.meilisearch.com/reference/api/indexes.html#list-all-indexes
+            parameters accepted by the get indexes route: https://www.meilisearch.com/docs/reference/api/indexes#list-all-indexes
 
         Returns
         -------
@@ -141,7 +151,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         if parameters is None:
             parameters = {}
@@ -164,7 +174,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return Index(self.config, uid).fetch_info()
 
@@ -185,7 +195,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.http.get(f"{self.config.paths.index}/{uid}")
 
@@ -214,7 +224,7 @@ class Client:
         ----------
         queries:
             List of dictionaries containing the specified indexes and their search queries
-            https://docs.meilisearch.com/reference/api/search.html#search-in-an-index
+            https://www.meilisearch.com/docs/reference/api/search#search-in-an-index
 
         Returns
         -------
@@ -224,7 +234,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.http.post(
             f"{self.config.paths.multi_search}",
@@ -235,7 +245,7 @@ class Client:
         """Get all stats of Meilisearch
 
         Get information about database size and all indexes
-        https://docs.meilisearch.com/reference/api/stats.html
+        https://www.meilisearch.com/docs/reference/api/stats
 
         Returns
         -------
@@ -245,7 +255,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.http.get(self.config.paths.stat)
 
@@ -260,7 +270,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.http.get(self.config.paths.health)
 
@@ -284,12 +294,12 @@ class Client:
         -------
         key:
             The API key.
-            https://docs.meilisearch.com/reference/api/keys.html#get-key
+            https://www.meilisearch.com/docs/reference/api/keys#get-key
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         key = self.http.get(f"{self.config.paths.keys}/{key_or_uid}")
 
@@ -301,18 +311,18 @@ class Client:
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the get keys route: https://docs.meilisearch.com/reference/api/keys.html#get-all-keys
+            parameters accepted by the get keys route: https://www.meilisearch.com/docs/reference/api/keys#get-all-keys
 
         Returns
         -------
         keys:
             API keys.
-            https://docs.meilisearch.com/reference/api/keys.html#get-keys
+            https://www.meilisearch.com/docs/reference/api/keys#get-keys
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         if parameters is None:
             parameters = {}
@@ -336,12 +346,12 @@ class Client:
         -------
         key:
             The new API key.
-            https://docs.meilisearch.com/reference/api/keys.html#get-keys
+            https://www.meilisearch.com/docs/reference/api/keys#get-keys
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         task = self.http.post(f"{self.config.paths.keys}", options)
 
@@ -362,12 +372,12 @@ class Client:
         -------
         key:
             The updated API key.
-            https://docs.meilisearch.com/reference/api/keys.html#get-keys
+            https://www.meilisearch.com/docs/reference/api/keys#get-keys
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         url = f"{self.config.paths.keys}/{key_or_uid}"
         key = self.http.patch(url, options)
@@ -386,12 +396,12 @@ class Client:
         -------
         keys:
             The Response status code. 204 signifies a successful delete.
-            https://docs.meilisearch.com/reference/api/keys.html#get-keys
+            https://www.meilisearch.com/docs/reference/api/keys#get-keys
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         response = self.http.delete(f"{self.config.paths.keys}/{key_or_uid}")
 
@@ -408,7 +418,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.http.get(self.config.paths.version)
 
@@ -423,7 +433,7 @@ class Client:
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.get_version()
 
@@ -434,12 +444,12 @@ class Client:
         -------
         Dump:
             Information about the dump.
-            https://docs.meilisearch.com/reference/api/dump.html#create-a-dump
+            https://www.meilisearch.com/docs/reference/api/dump#create-a-dump
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         task = self.http.post(self.config.paths.dumps)
 
@@ -457,38 +467,37 @@ class Client:
         -------
         task_info:
             TaskInfo instance containing information about a task to track the progress of an asynchronous process.
-            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return TaskInfo(**self.http.post(self.config.paths.swap, parameters))
 
-    def get_tasks(
-        self, parameters: Optional[Dict[str, Any]] = None
-    ) -> Dict[str, List[Dict[str, Any]]]:
+    def get_tasks(self, parameters: Optional[Dict[str, Any]] = None) -> TaskResults:
         """Get all tasks.
 
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the get tasks route: https://docs.meilisearch.com/reference/api/tasks.html#get-tasks.
+            parameters accepted by the get tasks route: https://www.meilisearch.com/docs/reference/api/tasks#get-tasks.
 
         Returns
         -------
         task:
-            Dictionary with limit, from, next and results containing a list of all enqueued, processing, succeeded or failed tasks.
+            TaskResult instance containing limit, from, next and results containing a list of all
+            enqueued, processing, succeeded or failed tasks.
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.task_handler.get_tasks(parameters=parameters)
 
-    def get_task(self, uid: int) -> Dict[str, Any]:
+    def get_task(self, uid: int) -> Task:
         """Get one task.
 
         Parameters
@@ -499,12 +508,12 @@ class Client:
         Returns
         -------
         task:
-            Dictionary containing information about the processed asynchronous task.
+            Task instance containing information about the processed asynchronous task.
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.task_handler.get_task(uid)
 
@@ -513,19 +522,19 @@ class Client:
 
         Parameters
         ----------
-        parameters (optional):
-            parameters accepted by the cancel tasks route:https://docs.meilisearch.com/reference/api/tasks.html#cancel-tasks.
+        parameters:
+            parameters accepted by the cancel tasks route:https://www.meilisearch.com/docs/reference/api/tasks#cancel-tasks.
 
         Returns
         -------
         task_info:
             TaskInfo instance containing information about a task to track the progress of an asynchronous process.
-            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.task_handler.cancel_tasks(parameters=parameters)
 
@@ -535,16 +544,16 @@ class Client:
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the delete tasks route:https://docs.meilisearch.com/reference/api/tasks.html#delete-task.
+            parameters accepted by the delete tasks route:https://www.meilisearch.com/docs/reference/api/tasks#delete-task.
         Returns
         -------
         task_info:
             TaskInfo instance containing information about a task to track the progress of an asynchronous process.
-            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.task_handler.delete_tasks(parameters=parameters)
 
@@ -553,7 +562,7 @@ class Client:
         uid: int,
         timeout_in_ms: int = 5000,
         interval_in_ms: int = 50,
-    ) -> Dict[str, Any]:
+    ) -> Task:
         """Wait until Meilisearch processes a task until it fails or succeeds.
 
         Parameters
@@ -568,12 +577,12 @@ class Client:
         Returns
         -------
         task:
-            Dictionary containing information about the processed asynchronous task.
+            Task instance containing information about the processed asynchronous task.
 
         Raises
         ------
         MeilisearchTimeoutError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         return self.task_handler.wait_for_task(uid, timeout_in_ms, interval_in_ms)
 
@@ -616,7 +625,7 @@ class Client:
             raise ValueError("An uid is required and must comply to the uuid4 format.")
         if not search_rules or search_rules == [""]:
             raise ValueError("The search_rules field is mandatory and should be defined.")
-        if expires_at and expires_at < datetime.datetime.utcnow():
+        if expires_at and expires_at < datetime.datetime.now(tz=datetime.timezone.utc):
             raise ValueError("The date expires_at should be in the future.")
 
         # Standard JWT header for encryption with SHA256/HS256 algorithm
