@@ -2,13 +2,13 @@ from __future__ import annotations
 
 from datetime import datetime
 from time import sleep
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, Optional
 from urllib import parse
 
 from meilisearch._httprequests import HttpRequests
 from meilisearch.config import Config
 from meilisearch.errors import MeilisearchTimeoutError
-from meilisearch.models.task import TaskInfo
+from meilisearch.models.task import Task, TaskInfo, TaskResults
 
 
 class TaskHandler:
@@ -16,7 +16,7 @@ class TaskHandler:
     A class covering the Meilisearch Task API
 
     The task class gives access to all task routes and gives information about the progress of asynchronous operations.
-    https://docs.meilisearch.com/reference/api/tasks.html
+    https://www.meilisearch.com/docs/reference/api/tasks
     """
 
     def __init__(self, config: Config):
@@ -27,34 +27,34 @@ class TaskHandler:
         self.config = config
         self.http = HttpRequests(config)
 
-    def get_tasks(
-        self, parameters: Optional[Dict[str, Any]] = None
-    ) -> Dict[str, List[Dict[str, Any]]]:
+    def get_tasks(self, parameters: Optional[Dict[str, Any]] = None) -> TaskResults:
         """Get all tasks.
 
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the get tasks route: https://docs.meilisearch.com/reference/api/tasks.html#get-tasks.
+            parameters accepted by the get tasks route: https://www.meilisearch.com/docs/reference/api/tasks#get-tasks.
 
         Returns
         -------
         task:
-            Dictionary with limit, from, next and results containing a list of all enqueued, processing, succeeded or failed tasks.
+            TaskResults instance contining limit, from, next and results containing a list of all
+            enqueued, processing, succeeded or failed tasks.
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         if parameters is None:
             parameters = {}
         for param in parameters:
             if isinstance(parameters[param], list):
                 parameters[param] = ",".join(parameters[param])
-        return self.http.get(f"{self.config.paths.task}?{parse.urlencode(parameters)}")
+        tasks = self.http.get(f"{self.config.paths.task}?{parse.urlencode(parameters)}")
+        return TaskResults(tasks)
 
-    def get_task(self, uid: int) -> Dict[str, Any]:
+    def get_task(self, uid: int) -> Task:
         """Get one task.
 
         Parameters
@@ -65,36 +65,35 @@ class TaskHandler:
         Returns
         -------
         task:
-            Dictionary containing information about the status of the asynchronous task.
+            Task instance containing information about the processed asynchronous task.
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
-        return self.http.get(f"{self.config.paths.task}/{uid}")
+        task = self.http.get(f"{self.config.paths.task}/{uid}")
+        return Task(**task)
 
-    def cancel_tasks(self, parameters: Optional[Dict[str, Any]] = None) -> TaskInfo:
+    def cancel_tasks(self, parameters: Dict[str, Any]) -> TaskInfo:
         """Cancel a list of enqueued or processing tasks.
 
         Parameters
         ----------
-        parameters (optional):
-            parameters accepted by the cancel tasks https://docs.meilisearch.com/reference/api/tasks.html#cancel-task.
+        parameters:
+            parameters accepted by the cancel tasks https://www.meilisearch.com/docs/reference/api/tasks#cancel-task.
 
         Returns
         -------
         task_info:
             TaskInfo instance containing information about a task to track the progress of an asynchronous process.
-            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
 
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
-        if parameters is None:
-            parameters = {}
         for param in parameters:
             if isinstance(parameters[param], list):
                 parameters[param] = ",".join(parameters[param])
@@ -108,16 +107,16 @@ class TaskHandler:
         config:
             Config object containing permission and location of Meilisearch.
         parameters (optional):
-            parameters accepted by the delete tasks route:https://docs.meilisearch.com/reference/api/tasks.html#delete-task.
+            parameters accepted by the delete tasks route:https://www.meilisearch.com/docs/reference/api/tasks#delete-task.
         Returns
         -------
         task_info:
             TaskInfo instance containing information about a task to track the progress of an asynchronous process.
-            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
         Raises
         ------
         MeilisearchApiError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         if parameters is None:
             parameters = {}
@@ -132,7 +131,7 @@ class TaskHandler:
         uid: int,
         timeout_in_ms: int = 5000,
         interval_in_ms: int = 50,
-    ) -> Dict[str, Any]:
+    ) -> Task:
         """Wait until the task fails or succeeds in Meilisearch.
 
         Parameters
@@ -147,18 +146,18 @@ class TaskHandler:
         Returns
         -------
         task:
-            Dictionary containing information about the processed asynchronous task.
+            Task instance containing information about the processed asynchronous task.
 
         Raises
         ------
         MeilisearchTimeoutError
-            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
         """
         start_time = datetime.now()
         elapsed_time = 0.0
         while elapsed_time < timeout_in_ms:
             task = self.get_task(uid)
-            if task["status"] not in ("enqueued", "processing"):
+            if task.status not in ("enqueued", "processing"):
                 return task
             sleep(interval_in_ms / 1000)
             time_delta = datetime.now() - start_time
